iCalendar feed widget
=====================

This widget displays the upcoming events of an online calendar on the dashboard. 
The events are shown with their title and the exact date range.
Calendar widgets that can't load or parse the calendar data will 
be marked as broken. How to handle broken widgets is explained in :ref:`core-configure-dashboard-widgets`.

* **iCalendar feed source URL**: The URL of the iCalendar feed
* **Base URL**: The widget will have a link to visit a related website to see more events.
* **Number of displayed counts**: With this option, you can configure how many events should be shown in the widget.

.. image:: ../_static/create_ical_widget.png
  :width: 100%
  :alt: Create an iCalendar widget
